# -*- coding: cp1252 -*-

# Importamos modulos

import random
import pygame
from pygame.locals import *
from classes import *
from config import *
import sys

# Inicializamos el mezclador de sonido
pygame.mixer.init(frequency=22050, size=-16, channels=2, buffer=4096)
# Y creamos varios canales, para poder superponer sonidos sin problemas
pygame.mixer.set_num_channels(16)

musicamenu = 'data/sonidos/sexbomb.ogg'
ch_musicamenu = pygame.mixer.Channel(1)

menuatras = 'data/sonidos/menu_select_7.wav'
ch_menuatras = pygame.mixer.Channel(8)

# Por defecto el sonido estar activado, se desactivar desde el men Opciones
sonido = True

# Clases

class Opcion:

    def __init__(self, fuente, titulo, x, y, paridad, funcion_asignada):
        # Creamos diferentes imagenes, una normal, una de una opcion seleccionada y otra para el sonido apagado
        self.imagen_normal = fuente.render(titulo, 1, (255, 255, 255))
        self.imagen_destacada = fuente.render(titulo, 1, (0, 255, 0))
        self.imagen_off = fuente.render(titulo, 1, (255, 0, 0))
        self.image = self.imagen_normal
        self.rect = self.image.get_rect()
        self.rect.x = 500 * paridad
        self.rect.y = y
        # Cada opcion tendr asignada una funcin
        self.funcion_asignada = funcion_asignada
        self.x = float(self.rect.x)

    def actualizar(self):
        destino_x = 105
        self.x += (destino_x - self.x) / 5.0
        self.rect.x = int(self.x)

    def imprimir(self, screen):
        screen.blit(self.image, self.rect)

    def destacar(self, estado):
        # Detectar si es la opcion sobre la que estamos situados o no y la sealizar como corresponde
        if estado:
            self.image = self.imagen_destacada
        else:
            self.image = self.imagen_normal

    def activar(self):
        # Activa la funcin deseada
        self.funcion_asignada()
        
    def off(self):
        global sonido
        # Marcar en rojo la opcion de sonido, para saber si lo tenemos desactivado
        if not sonido:
            self.image = self.imagen_off
        else:
            self.image = self.imagen_normal

class Cursor:

    def __init__(self, x, y, dy):
        # Cargamos la imagen deseada para el cursor del menu
        self.image = pygame.image.load(CURSOR).convert_alpha()
        self.image = pygame.transform.scale(self.image, (60, 60))
        self.rect = self.image.get_rect()
        self.rect.x = x
        self.y_inicial = y
        self.dy = dy
        self.y = 0
        self.seleccionar(0)

    def actualizar(self):
        # Situamos el cursor a la altura de la opcion correspondiente
        self.y += (self.to_y - self.y) / 10.0
        self.rect.y = int(self.y)

    def seleccionar(self, indice):
        # Guardaremos la posicion de la opcion deseada para poder situar el cursor
        self.to_y = self.y_inicial + indice * self.dy

    def imprimir(self, screen):
        screen.blit(self.image, self.rect)

class Menu:
    # Representa un menu con opciones
    
    def __init__(self, opciones):
        # Creamos una lista vacia para meter las opciones
        self.opciones = []
        # Aqui ponemos el titulo que queramos para el juego
        self.titulo = TITULO_JUEGO
        # Esta ser la fuente para el titulo y su tamao
        self.fuentet = pygame.font.Font(TITLE_FONT, 80)
        # Esta la fuente de las opciones y su tamao
        self.fuenteo = pygame.font.Font(OPTIONS_FONT, 40)
        self.titulom = self.fuentet.render(self.titulo, True, (255,0,255))
        # Creamos el canal donde estar la musica del menu
        self.ch_menuseleccion = pygame.mixer.Channel(10)
        self.menuseleccion = 'data/sonidos/menu_back_14.wav'

        # Est ser la posicin x del menu
        x = 105
        
        # Estas son otras variables que pasaremos a la clase Opcion para colocar el menu
        y = ALTO - 350
        paridad = 1
        
        # Creamos el cursor
        self.cursor = Cursor(x - 80, y-10, 60)
        
        # Y creamos cada opcion, desde la lista que le demos
        for titulo, funcion in opciones:
            self.opciones.append(Opcion(self.fuenteo, titulo, x, y, paridad, funcion))
            # Esta ser la distancia entre las opciones mostradas
            y += 60
            if paridad == 1:
                paridad = -1
            else:
                paridad = 1

        self.seleccionado = 0
        self.total = len(self.opciones)
        self.mantiene_pulsado = False

    def actualizar(self):
        # Altera el valor de la opcion seleccionada con las flechas
        global ANCHO, ALTO
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        # Capturamos las teclas pulsadas
        k = pygame.key.get_pressed()
        
        # Con la tecla Esc vamos nos preguntar si queremos salir o no
        if k[K_ESCAPE]:
            menuexit()
        
        # Segun la tecla que pulsemos modificamos la opcion seleccionada
        if not self.mantiene_pulsado:
            if k[K_UP]:
                self.seleccionado -= 1
            elif k[K_DOWN]:
                self.seleccionado += 1
            elif k[K_RETURN]:
                # Si tiene sonido, ejecuta el sonido deseado cuando elegimos una opcion
                if sonido:
                    self.ch_menuseleccion.play(pygame.mixer.Sound(self.menuseleccion))
                    time.sleep(0.1)
                # Invoca a la funcin asociada a la opcin.
                self.opciones[self.seleccionado].activar()
            # Con las teclas F12 y F11 cambiaremos a modo de pantalla completa o no
            if k[K_F12]:
                screen = pygame.display.set_mode((0, 0),pygame.FULLSCREEN)
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
            if k[K_F11]:
                screen = pygame.display.set_mode((ANCHO, ALTO))
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
        
            
        # Mantenemos el cursor entre las opciones permitidas
        if self.seleccionado < 0:
            self.seleccionado = 0
        elif self.seleccionado > self.total - 1:
            self.seleccionado = self.total - 1
        
        self.cursor.seleccionar(self.seleccionado)

        # Indica si el usuario mantiene pulsada alguna tecla.
        self.mantiene_pulsado = k[K_UP] or k[K_DOWN] or k[K_RETURN]
        
        self.cursor.actualizar()
        
        # Actualizamos cada opcion
        for o in self.opciones:
            o.actualizar()

    def imprimir(self, screen):
        # Imprime en la pantalla cada linea de texto de la opcion del men        
        self.cursor.imprimir(screen)
        screen.blit(self.titulom, ((ANCHO / 2) - self.fuentet.size(self.titulo)[0] / 2, 20))
        for opcion in self.opciones:
            if opcion == self.opciones[self.seleccionado]:
                self.opciones[self.seleccionado].destacar(True)
            else:
                self.opciones[self.seleccionado].destacar(False)
            opcion.imprimir(screen)

class MenuOpc:
    # Representa un menu con opciones
    def __init__(self, opciones): 
        # Creamos una lista vacia para meter las opciones             
        self.opciones = []
        # Aqui ponemos el titulo que queramos para el juego
        self.titulo = TITULO_JUEGO
        # Esta ser la fuente para el titulo y su tamao
        self.fuentet = pygame.font.Font(TITLE_FONT, 80)
        # Esta la fuente de las opciones y su tamao
        self.fuenteo = pygame.font.Font(OPTIONS_FONT, 40)
        self.titulom = self.fuentet.render(self.titulo, True, (255,0,255))
        # Creamos el canal donde estar la musica del menu
        self.menuatras = 'data/sonidos/menu_select_7.wav'
        self.menuseleccion = 'data/sonidos/menu_back_14.wav'
        self.ch_menuseleccion = pygame.mixer.Channel(10)
        
        # Est ser la posicin x del menu
        x = 105
        
        # Estas son otras variables que pasaremos a la clase Opcion para colocar el menu
        y = ALTO - 350
        paridad = 1
        
        # Creamos el cursor
        self.cursor = Cursor(x - 80, y-10, 60)
        
        # Y creamos cada opcion, desde la lista que le demos
        for titulo, funcion in opciones:
            self.opciones.append(Opcion(self.fuenteo, titulo, x, y, paridad, funcion))
            # Esta ser la distancia entre las opciones mostradas
            y += 60
            if paridad == 1:
                paridad = -1
            else:
                paridad = 1

        self.seleccionado = 0
        self.total = len(self.opciones)
        self.mantiene_pulsado = False

    def actualizar(self):
        # Altera el valor de la opcion seleccionada con las flechas
        global sonido
        global menuatras
        global ch_musicamenu
        global ch_menuatras
        global ANCHO, ALTO
        
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        
        # Capturamos las teclas pulsadas
        k = pygame.key.get_pressed()
        
        # Con la tecla Esc vamos nos preguntar si queremos salir o no
        if k[K_ESCAPE]:
            menuexit()
        
        # Segun la tecla que pulsemos modificamos la opcion seleccionada
        if not self.mantiene_pulsado:
            if k[K_UP]:
                self.seleccionado -= 1
            elif k[K_DOWN]:
                self.seleccionado += 1
            # Si la opcion elegida es la de sonido
            elif k[K_RETURN] and self.seleccionado == 0:
                # Invertiremos el valor de sonido
                sonido = not sonido
                # Si quitamos el sonido, pararemos todos los sonidos
                if not sonido:
                    pygame.mixer.stop()
                # Si ponemos el sonido, volver a comenzar la musica del menu
                if sonido:
                    self.ch_menuseleccion.play(pygame.mixer.Sound(self.menuseleccion))
                    time.sleep(0.1)
                    ch_musicamenu.play(pygame.mixer.Sound(musicamenu), True)
            # Si pulsamos Intro sobre cualquier otra opcion
            elif k[K_RETURN]:
                # Invocar a la funcin asociada a la opcin.
                if sonido:
                    self.ch_menuseleccion.play(pygame.mixer.Sound(self.menuseleccion))
                    time.sleep(0.1)
                self.opciones[self.seleccionado].activar()
            # Si pulsamos la tecla de Borrado volveremos al men anterior
            elif k[K_BACKSPACE]:
                if sonido:
                    ch_menuatras.play(pygame.mixer.Sound(menuatras))
                menuprincipal()
                return 0
            
            # Con las teclas F12 y F11 cambiaremos a modo de pantalla completa o no
            if k[K_F12]:
                screen = pygame.display.set_mode((0, 0),pygame.FULLSCREEN)
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
            if k[K_F11]:
                screen = pygame.display.set_mode((ANCHO, ALTO))
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
                     
        # Mantenemos el cursor entre las opciones permitidas
        if self.seleccionado < 0:
            self.seleccionado = 0
        elif self.seleccionado > self.total - 1:
            self.seleccionado = self.total - 1
        
        self.cursor.seleccionar(self.seleccionado)

        # Indica si el usuario mantiene pulsada alguna tecla.
        self.mantiene_pulsado = k[K_UP] or k[K_DOWN] or k[K_RETURN]
        
        self.cursor.actualizar()
        
        # Actualizamos cada opcion
        for o in self.opciones:
            o.actualizar()

    def imprimir(self, screen):
        # Imprime en la pantalla cada linea de texto de la opcion del men
        self.cursor.imprimir(screen)
        screen.blit(self.titulom, ((ANCHO / 2) - self.fuentet.size(self.titulo)[0] / 2, 20))
        for opcion in self.opciones:
            if opcion == self.opciones[self.seleccionado]:
                self.opciones[self.seleccionado].destacar(True)
            else:
                # Si la opcion es Sonido
                if opcion == self.opciones[0]:
                    # Y sonido est desactivado
                    if not sonido:
                        # Lo sealizaremos activando esta funcin
                        self.opciones[0].off()
                self.opciones[self.seleccionado].destacar(False)
            opcion.imprimir(screen)

class MenuSalir:
    # Representa un menu con opciones
    def __init__(self, opciones): 
        # Creamos una lista vacia para meter las opciones             
        self.opciones = []
        # Aqui ponemos el titulo que queramos para el juego
        self.titulo = TITULO_JUEGO
        # Esta ser la fuente para el titulo y su tamao
        self.fuentet = pygame.font.Font(TITLE_FONT, 80)
        # Esta la fuente de las opciones y su tamao
        self.fuenteo = pygame.font.Font(OPTIONS_FONT, 40)
        self.titulom = self.fuentet.render(self.titulo, True, (255,0,255))
        # Creamos el canal donde estar la musica del menu
        self.menuatras = 'data/sonidos/menu_select_7.wav'
        self.menuseleccion = 'data/sonidos/menu_back_14.wav'
        self.ch_menuseleccion = pygame.mixer.Channel(10)
        
        # Est ser la posicin x del menu
        x = 105
        
        # Estas son otras variables que pasaremos a la clase Opcion para colocar el menu
        y = ALTO - 350
        paridad = 1
        
        # Creamos el cursor
        self.cursor = Cursor(x - 80, y-10, 60)
        
        # Y creamos cada opcion, desde la lista que le demos
        for titulo, funcion in opciones:
            self.opciones.append(Opcion(self.fuenteo, titulo, x, y, paridad, funcion))
            # Esta ser la distancia entre las opciones mostradas
            y += 60
            if paridad == 1:
                paridad = -1
            else:
                paridad = 1

        self.seleccionado = 0
        self.total = len(self.opciones)
        self.mantiene_pulsado = False

    def actualizar(self):
        # Altera el valor de la opcion seleccionada con las flechas
        global menuatras
        global ch_musicamenu
        global ch_menuatras
        global ANCHO, ALTO
        
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        
        # Capturamos las teclas pulsadas
        k = pygame.key.get_pressed()
        
        # Segun la tecla que pulsemos modificamos la opcion seleccionada
        if not self.mantiene_pulsado:
            if k[K_UP]:
                self.seleccionado -= 1
            elif k[K_DOWN]:
                self.seleccionado += 1
            elif k[K_RETURN] and self.seleccionado == 0:
                # Invocar a la funcin asociada a la opcin.
                if sonido:
                    self.ch_menuseleccion.play(pygame.mixer.Sound(self.menuseleccion))
                    time.sleep(0.1)
                salir = True
                return salir
            # Si pulsamos Intro sobre cualquier otra opcion
            elif k[K_RETURN] and self.seleccionado == 1:
                # Invocar a la funcin asociada a la opcin.
                if sonido:
                    self.ch_menuseleccion.play(pygame.mixer.Sound(self.menuseleccion))
                    time.sleep(0.1)
                self.opciones[self.seleccionado].activar()
            # Si pulsamos la tecla de Borrado volveremos al men anterior
            elif k[K_BACKSPACE]:
                if sonido:
                    ch_menuatras.play(pygame.mixer.Sound(menuatras))
                menuprincipal()
                return salir
            
            # Con las teclas F12 y F11 cambiaremos a modo de pantalla completa o no
            if k[K_F12]:
                screen = pygame.display.set_mode((0, 0),pygame.FULLSCREEN)
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
            if k[K_F11]:
                screen = pygame.display.set_mode((ANCHO, ALTO))
                info = pygame.display.Info()
                ALTO, ANCHO = info.current_h, info.current_w
                     
        # Mantenemos el cursor entre las opciones permitidas
        if self.seleccionado < 0:
            self.seleccionado = 0
        elif self.seleccionado > self.total - 1:
            self.seleccionado = self.total - 1
        
        self.cursor.seleccionar(self.seleccionado)

        # Indica si el usuario mantiene pulsada alguna tecla.
        self.mantiene_pulsado = k[K_UP] or k[K_DOWN] or k[K_RETURN]
        
        self.cursor.actualizar()
        
        # Actualizamos cada opcion
        for o in self.opciones:
            o.actualizar()

    def imprimir(self, screen):
        # Imprime en la pantalla cada linea de texto de la opcion del men
        self.cursor.imprimir(screen)
        screen.blit(self.titulom, ((ANCHO / 2) - self.fuentet.size(self.titulo)[0] / 2, 20))
        for opcion in self.opciones:
            if opcion == self.opciones[self.seleccionado]:
                self.opciones[self.seleccionado].destacar(True)
            else:
                self.opciones[self.seleccionado].destacar(False)
            opcion.imprimir(screen)
# Funciones

def GameOver():
    ch_musicagameover = pygame.mixer.Channel(3)
    musicagameover = 'data/sonidos/sexbomb.ogg'
    ch_sonidogo = pygame.mixer.Channel(12)
    sonidogo = 'data/sonidos/gameover.wav'
    ch_sonidogo.play(pygame.mixer.Sound(sonidogo))
    ch_musicagameover.play(pygame.mixer.Sound(musicagameover))
    
def comenzar_nuevo_juego():
    global ANCHO, ALTO
    # Paramos todos los canales de sonido que estuvieran activos
    pygame.mixer.stop()
    ch_musicajuego = pygame.mixer.Channel(2)   
    ch_sonidonivel = pygame.mixer.Channel(11)    
    musicajuego ='data/sonidos/level1.ogg'    
    sonidonivel = 'data/sonidos/vel1.wav'
    
    # Si tenemos el sonido activado, comenzar la msica del juego en si
    if sonido:
        ch_musicajuego.play(pygame.mixer.Sound(musicajuego), True)
    pygame.font.init()
    screen = pygame.display.set_mode((ANCHO, ALTO))
    info = pygame.display.Info()
    ALTO, ANCHO = info.current_h, info.current_w
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    tiempo = pygame.time.Clock()
    
    # Variables
    
    contadormalo = 0
    muerto = False
    score = 0
    vidas = 3
    tm = 59
    tmr = 0
    tmv = 0
    nivel = 1
    x = 0
    malos = []
    actual = 0
    contador = 0
    stayv = False
    turn = True
    colis = False
    contmuer = 0
    isvida = False

    
    # Creacion de personajes y objetos
    pprin = PPrincipal()
    objetivo = Objetivo()
    vel = Velocidad()
    
    # Fuente con la que mostramos las Vidas, Puntos y Nivel
    fuente = pygame.font.Font(GAME_FONT,30)
    fuentego = pygame.font.Font(GAMEOVER_FONT,120)
    
    jugar = True
    
    while jugar:
        tiempo.tick(30)
        contadormalo += 1
        keys = pygame.key.get_pressed()
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        # Con la tecla Esc vamos nos preguntar si queremos salir o no
        if keys[K_ESCAPE]:
            menuexit()
        # Con la tecla de borrado volveremos del juego al men anterior
        if keys[K_BACKSPACE]:
            pygame.mixer.stop()
            if sonido:
                ch_menuatras.play(pygame.mixer.Sound(menuatras))
                ch_musicamenu.play(pygame.mixer.Sound(musicamenu), True)
            return 0
        # Las teclas F12 y F11 se usarn para ejecutar el juego en modo de pantalla completa o no
        if keys[K_F12]:
            screen = pygame.display.set_mode((0, 0),pygame.FULLSCREEN)
            info = pygame.display.Info()
            ALTO, ANCHO = info.current_h, info.current_w
            fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
        if keys[K_F11]:
            screen = pygame.display.set_mode((ANCHO, ALTO))
            info = pygame.display.Info()
            ALTO, ANCHO = info.current_h, info.current_w
            fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
        # El malo esperar 30 bucles para aparecer, o aadir otro malo al pasar de nivel
        if contadormalo > 30:
            if actual != nivel:
                if (nivel % 2) != 0:
                    malos.append(PMalo())
                    actual = nivel
        # Mientras el personaje principal sigue vivo, todos los objetos siguen moviendose
        if muerto == False:    
            tm, tmr, muerto, score= pprin.mover(objetivo, tm, screen, keys, tmr, vel, vidas, score, muerto, sonido)
            tm, stay = objetivo.mueve(tm, ALTO, ANCHO)
            tmr, stayr = vel.mueve(tmr, ALTO, ANCHO)
        
        # Primero ponemos el fondo
        screen.blit(fondo, (0,0))
        
        # Sobre l dibujamos los objetos
        if stay:
            objetivo.dibuja(muerto, screen)    
        if stayr:
            vel.dibuja(muerto, screen)
            stayr = False 
        if nivel == 4 and turn:
            isvida = True
            vida = Vida()
            turn = False
        tmv += 1
        print tmv
        if nivel > 3:
            vidas, tmv, colis = vida.colision(vidas, pprin, tmv, colis)
            
        # Tambin dibujamos el personaje principal
        pprin.dibujar(screen)
        # Los malos aparecern solo mientras la vaca siga viva y hayan pasado los 30 bucles
        if contadormalo > 30:
            for malo in malos:
                contadormalo, vidas, contador = malo.mover(pprin, contadormalo, vidas, contador, sonido)
                malo.dibujar(screen, muerto)
    
    # Subir de nivel
        
        if score > 0 and score % 10 == 0:
            turn = True
            if sonido:
                ch_sonidonivel.play(pygame.mixer.Sound(sonidonivel))
            score = 0
            nivel += 1
            tmv = 0
            if isvida:
                tmv, stayv, colis = vida.mueve(tmv, ALTO, ANCHO, stayv, colis)
            if (nivel % 2) == 0:
                malos[len(malos)-1].sube_nivel()
        if tmv < 60 and isvida:
            vida.dibuja(muerto, screen)    
    # Mostrar Puntuacion
        if not muerto:
            texto_puntuacion = '.. Vidas '+ str(vidas) + ' .. Puntos ' + str(score)+ ' .. Nivel '+ str(nivel)+' ..'
        if muerto:
            if sonido and contmuer == 0:
                GameOver()
            contmuer += 1
            texto_puntuacion = ' .. Puntos ' + str(score+((nivel-1)*10))+ ' .. Nivel '+ str(nivel)+' ..'
            texto_GO = 'GAME OVER'
            GO_text = fuentego.render(texto_GO, True, (0, 0, 0))
        score_text = fuente.render(texto_puntuacion, True, (0, 0, 0))
        screen.blit(score_text, ((ANCHO / 2) - fuente.size(texto_puntuacion)[0] / 2, 5))
        if muerto:
            screen.blit(GO_text, ((ANCHO / 2) - fuente.size(texto_GO)[0], ALTO/2))
        
        pygame.display.flip()
        
        time.sleep(0.07)
        if muerto:
            x += 1
        if x == 25:
            if sonido:
                pygame.mixer.stop()
                ch_musicamenu.play(pygame.mixer.Sound(musicamenu), True)
            menu2()
                        
def mostrar_opciones():
    salir = False
    # Creamos las opciones deseadas
    opciones = [
        ("Sonido", salir_del_programa),
        ("Menu Principal", menuprincipal),
        ("Salir", salir_del_programa)
        ]        
    pygame.font.init()
    screen = pygame.display.set_mode((ANCHO, ALTO))
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    # Creamos el menu con esas opciones
    menu = MenuOpc(opciones)
    
    
    while not salir:
        for e in pygame.event.get():
            if e.type == QUIT:
                salir = True
                exit()

        screen.blit(fondo, (0, 0))
        menu.actualizar()
        menu.imprimir(screen)

        pygame.display.flip()
        pygame.time.delay(10)
    
def mostrar_instrucciones():
    titulo = TITULO_JUEGO
    fuentet = pygame.font.Font(TITLE_FONT, 80)
    titulom = fuentet.render(titulo, True, (255,0,255))
    # Creamos el texto de las instrucciones por lineas
    texto_ins = [' Mueve a la vaca utilizando las flechas', 
                 'de direccion y trata de conseguir comerte',
                 'toda la alfalfa posible que ira apareciendo',
                 'en pantalla, aunque deberas tener cuidado',
                 'con las pelotas, si te da te quitara vidas,',
                 'aunque tambien puede aparecer un rayo, el',
                 'cual te dara velocidad para poder huir de ',
                 'ellas mas facilmente.',
                 'Suerte.']
    fijar = True
    screen = pygame.display.set_mode((ANCHO, ALTO))
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    while fijar:
        keys = pygame.key.get_pressed()
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        # Con la tecla Esc vamos nos preguntar si queremos salir o no
        if keys[K_ESCAPE]:
            menuexit()
        fuente = pygame.font.Font(INS_FONT,50)
        x = 10+(ALTO / 3)
        b = 155
        screen.blit(fondo, (0, 0))
        # Dibujar cada frase en pantalla
        for frase in texto_ins:
            credit_text = fuente.render(frase, True, (b, 255, 0))            
            screen.blit(credit_text, ((ANCHO / 2) - fuente.size(frase)[0] / 2, x))
            # Con la variable x situaremos una linea debajo de otra
            x += 40
            # Con la variable b crearemos un degradado en el color del texto
            b += 10
        for evento in pygame.event.get():
            if evento.type == QUIT:
                exit()
        keys = pygame.key.get_pressed()
        # Para salir habr que pulsar la tecla de Retroceso
        if keys[K_BACKSPACE]:
            if sonido:
                ch_menuatras.play(pygame.mixer.Sound(menuatras))
            time.sleep(0.1)
            fijar = False
        screen.blit(titulom, (130,20))
        pygame.display.flip()

def creditos(): 
    fijar = True
    titulo = TITULO_JUEGO
    fuentet = pygame.font.Font(TITLE_FONT, 80)
    titulom = fuentet.render(titulo, True, (255,0,255))
    screen = pygame.display.set_mode((ANCHO, ALTO))
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    while fijar:
        keys = pygame.key.get_pressed()
        for evento in pygame.event.get():
            # Capturar el salir
            if evento.type == QUIT:
                sys.exit(0)
        # Con la tecla Esc vamos nos preguntar si queremos salir o no
        if keys[K_ESCAPE]:
            menuexit()   
        fuente = pygame.font.Font(CREDITS_FONT,60)
        # Creamos el texto de los creditos dividido en lineas
        texto = ['Desarrollado por:',
                 '                             Casandra Carazo',
                 'Agradecimientos a:',
                 '                             Nils Callizo']        
        screen.blit(fondo, (0, 0))
        b = 100
        x = 30+(ALTO / 3)
        # Dibujamos cada linea en pantalla
        for frase in texto:
            texto_cre = fuente.render(frase, True, (0, 255, b))            
            screen.blit(texto_cre, ((ANCHO / 3) - fuente.size(frase)[0] / 2, x))
            x += 80
            b += 50
        for evento in pygame.event.get():
            if evento.type == QUIT:
                exit()
        keys = pygame.key.get_pressed()
        # Para salir tendremos que pulsar la tecla Retroceso
        if keys[K_BACKSPACE]:
            if sonido:
                ch_menuatras.play(pygame.mixer.Sound(menuatras))
            time.sleep(0.1)
            fijar = False
        screen.blit(titulom, (130,20))
        pygame.display.flip()

def salir_del_programa():
    print " Gracias por utilizar este programa."
    sys.exit(0)

def menuprincipal():
    global ALTO, ANCHO
    salir = False
    # Creamos las opciones deseadas
    opciones = [
        ("Jugar", comenzar_nuevo_juego),
        ("Instrucciones", mostrar_instrucciones),
        ("Opciones", mostrar_opciones),   
        ("Creditos", creditos),
        ("Salir", salir_del_programa)
        ]

    pygame.font.init()
    screen = pygame.display.set_mode((ANCHO, ALTO))
    info = pygame.display.Info()
    ALTO, ANCHO = info.current_h, info.current_w
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    # Creamos el menu con esas opciones
    menu = Menu(opciones)

    while not salir:

        for e in pygame.event.get():
            if e.type == QUIT:
                salir = True

        screen.blit(fondo, (0, 0))
        menu.actualizar()
        menu.imprimir(screen)

        pygame.display.flip()
        pygame.time.delay(10)

def menu2():
    salir = False
    # Creamos las opciones deseadas
    opciones = [
        ("Jugar", comenzar_nuevo_juego),
        ("Menu Principal", menuprincipal),
        ("Salir", salir_del_programa)
        ]
        
    pygame.font.init()
    screen = pygame.display.set_mode((ANCHO, ALTO))
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    # Creamos el menu con esas opciones
    menu = Menu(opciones)

    while not salir:
        for e in pygame.event.get():
            if e.type == QUIT:
                salir = True
                exit()

        screen.blit(fondo, (0, 0))
        menu.actualizar()
        menu.imprimir(screen)

        pygame.display.flip()
        pygame.time.delay(10)

def menuexit():
    salir = False
    # Creamos las opciones deseadas
    opciones = [
        ("Continuar", salir_del_programa),
        ("Salir", salir_del_programa)
        ]
        
    pygame.font.init()
    screen = pygame.display.set_mode((ANCHO, ALTO))
    pygame.display.set_caption(TITULO_JUEGO)
    fondo = pygame.image.load("data/imagenes/fondo.jpg").convert()
    fondo = pygame.transform.scale(fondo, (ANCHO, ALTO))
    # Creamos el menu con esas opciones
    menu = MenuSalir(opciones)

    while not salir:
        for e in pygame.event.get():
            if e.type == QUIT:
                salir = True
                exit()

        screen.blit(fondo, (0, 0))
        salir = menu.actualizar()
        menu.imprimir(screen)

        pygame.display.flip()
        pygame.time.delay(10)
        
if __name__ == '__main__':
    # Al iniciar el juego, comenzar la msica
    if sonido:
        ch_musicamenu.play(pygame.mixer.Sound(musicamenu), True)
    # Y mostraremos el menu principal
    menuprincipal()
